@@ -15,6 +15,7 @@
 from __future__ import print_function
 
 import os
+import tempfile
 import sys
 import ply.yacc
 
@@ -22,7 +23,45 @@ from . import lexer
 from . import utility
 from .scope import Scope
 from .color import Color
-from lesscpy.plib import Block, Call, Deferred, Expression, Identifier, Mixin, Property, Statement, Variable
+from lesscpy.exceptions import CompilationError
+from lesscpy.plib import Block, Call, Deferred, Expression, Identifier, Mixin, Property, Statement, Variable, Import
+
+class ErrorRegister(object):
+    """
+
+    Raises CompilationError when an error occurs.
+
+    """
+    def __init__(self):
+        self.errors = []
+
+    def register(self, error):
+        self.errors.append(error)  # we could store them or just raise here.
+
+    def __close__(self):
+        if self.errors:
+            raise CompilationError("\n".join(self.errors))
+
+    close = __close__
+
+class PrintErrorRegister(object):
+    """
+
+    Colored error output to stderr.
+
+    """
+    def __init__(self):
+        self.has_errored = False
+
+    def register(self, error):
+        self.has_errored = True
+        color = '\x1b[31m' if error[0] == 'E' else '\x1b[33m'
+        print("%s%s\x1b[0m" % (color, error), end='\x1b[0m', file=sys.stderr)
+
+    def __close__(self):
+        pass
+
+    close = __close__
 
 
 class LessParser(object):
@@ -37,9 +76,10 @@ class LessParser(object):
                  tabfile='yacctab',
                  yacc_debug=False,
                  scope=None,
-                 outputdir='/tmp',
+                 outputdir=tempfile.gettempdir(),
                  importlvl=0,
-                 verbose=False
+                 verbose=False,
+                 fail_with_exc=False
                  ):
         """ Parser object
 
@@ -52,6 +92,8 @@ class LessParser(object):
                 outputdir (str): Output (debugging)
                 importlvl (int): Import depth
                 verbose (bool): Verbose mode
+                fail_with_exc (bool): Throw exception on syntax error instead
+                                      of printing to stderr
         """
         self.verbose = verbose
         self.importlvl = importlvl
@@ -76,20 +118,42 @@ class LessParser(object):
         self.stash = {}
         self.result = None
         self.target = None
+        self.fail_with_exc = fail_with_exc
+        if fail_with_exc:
+            self.register = ErrorRegister()
+        else:
+            self.register = PrintErrorRegister()
 
-    def parse(self, filename='', debuglevel=0):
+
+    def parse(self, filename=None, file=None, debuglevel=0):
         """ Parse file.
         kwargs:
             filename (str): File to parse
             debuglevel (int): Parser debuglevel
         """
-        if self.verbose:
-            print('Compiling target: %s' % filename, file=sys.stderr)
         self.scope.push()
+
+        if not file:
+            # We use a path.
+            file = filename
+        else:
+            # We use a stream and try to extract the name from the stream.
+            if hasattr(file, 'name'):
+                if filename is not None:
+                    raise AssertionError(
+                        'names of file and filename are in conflict')
+                filename = file.name()
+            else:
+                filename = '(stream)'
+
         self.target = filename
+        if self.verbose and not self.fail_with_exc:
+            print('Compiling target: %s' % filename, file=sys.stderr)
         self.result = self.parser.parse(
-            filename, lexer=self.lex, debug=debuglevel)
+            file, lexer=self.lex, debug=debuglevel)
+
         self.post_parse()
+        self.register.close()
 
     def post_parse(self):
         """ Post parse cycle. nodejs version allows calls to mixins
@@ -161,16 +225,21 @@ class LessParser(object):
         p[0].parse(None)
 
     def p_statement_import(self, p):
-        """ import_statement     : css_import t_ws css_string t_semicolon
+        """ import_statement     : css_import t_ws string t_semicolon
+                                 | css_import t_ws css_string t_semicolon
                                  | css_import t_ws css_string media_query_list t_semicolon
                                  | css_import t_ws fcall t_semicolon
                                  | css_import t_ws fcall media_query_list t_semicolon
         """
+        #import pdb; pdb.set_trace()
         if self.importlvl > 8:
             raise ImportError(
                 'Recrusive import level too deep > 8 (circular import ?)')
         if isinstance(p[3], str):
             ipath = utility.destring(p[3])
+        elif isinstance(p[3], list):
+            p[3] = Import(p[3], p.lineno(4)).parse(self.scope)
+            ipath = utility.destring(p[3])
         elif isinstance(p[3], Call):
             # NOTE(saschpe): Always in the form of 'url("...");', so parse it
             # and retrieve the inner css_string. This whole func is messy.
@@ -957,8 +1026,9 @@ class LessParser(object):
             t (Lex token): Error token
         """
         if t:
-            print("\x1b[31mE: %s line: %d, Syntax Error, token: `%s`, `%s`\x1b[0m"
-                  % (self.target, t.lineno, t.type, t.value), file=sys.stderr)
+            error_msg = "E: %s line: %d, Syntax Error, token: `%s`, `%s`" % \
+                      (self.target, t.lineno, t.type, t.value)
+            self.register.register(error_msg)
         while True:
             t = self.lex.token()
             if not t or t.value == '}':
@@ -975,7 +1045,5 @@ class LessParser(object):
             line (int): line number
             t(str): Error type
         """
-#        print(e.trace())
-        color = '\x1b[31m' if t == 'E' else '\x1b[33m'
-        print("%s%s: line: %d: %s\n" %
-              (color, t, line, e), end='\x1b[0m', file=sys.stderr)
+        self.register.register("%s: line: %d: %s\n" % (t, line, e))
+
