@@ -2,23 +2,23 @@
 """
 .. module:: lesscpy.plib
     :synopsis: Parse Nodes for Lesscpy
-    
+
     Copyright (c)
     See LICENSE for details.
-.. moduleauthor:: Jóhann T. Maríusson <jtm@robot.is>
+.. moduleauthor:: Johann T. Mariusson <jtm@robot.is>
 """
 __all__ = [
-   'Block', 
-   'Call', 
-   'Deferred',
-   'Expression', 
-   'Identifier',
-   'Mixin',
-   'Node',
-   'Property',
-   'Statement',
-   'String',
-   'Variable'
+    'Block',
+    'Call',
+    'Deferred',
+    'Expression',
+    'Identifier',
+    'Mixin',
+    'Node',
+    'Property',
+    'Statement',
+    'Variable'
+    'Import',
 ]
 from .block import Block
 from .call import Call
@@ -29,5 +29,5 @@ from .mixin import Mixin
 from .node import Node
 from .property import Property
 from .statement import Statement
-from .string import String
-from .variable import Variable
\ No newline at end of file
+from .variable import Variable
+from .import_ import Import
